@@ -26,6 +26,10 @@ modified by Pascal Brachet
 #include <QMessageBox>
 #include <QDebug>
 #include <QProgressBar>
+#include <QScrollBar>
+#include <QApplication>
+#include <QInputDialog>
+#include <QLineEdit>
 
 bool DocumentView::s_openUrl = false;
 
@@ -376,6 +380,9 @@ if (m_pages.count()<1) return;
 
             prepareScene();
             prepareView(left, top);
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
+	    viewport()->update();
+#endif
         }
 
         emit scaleFactorChanged(m_scaleFactor);
@@ -825,7 +832,7 @@ if (m_pages.count()<1) return;
 
 void DocumentView::on_pages_linkClicked(const QString& url)
 {
-	QUrl theurl = QUrl::fromEncoded(url.toAscii());
+	QUrl theurl = QUrl::fromEncoded(url.toLatin1());
 	QDesktopServices::openUrl(theurl);
 //     if(s_openUrl)
 //     {
@@ -1116,9 +1123,12 @@ void DocumentView::preparePages()
       progressDialog->setValue(index);
        //QApplication::processEvents();
         PageItem* page = new PageItem(&m_mutex, m_document->page(index), index);
-
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
+if (qApp->devicePixelRatio()==2) page->setPhysicalDpi(physicalDpiX()*2, physicalDpiY()*2);
+else page->setPhysicalDpi(physicalDpiX(), physicalDpiY());
+#else
         page->setPhysicalDpi(physicalDpiX(), physicalDpiY());
-
+#endif
         m_pagesScene->addItem(page);
         m_pages.append(page);
 
@@ -1452,6 +1462,7 @@ void DocumentView::showRect(int index, const QRectF &r)
 {
 QGraphicsRectItem* h=new QGraphicsRectItem();
 jumpToPage(index+1);
+if (index >= m_pages.count()) return;
 PageItem* page = m_pages.at(index);
 h->setPos(page->pos());
 h->setTransform(page->transform());
@@ -1460,6 +1471,7 @@ h->setVisible(true);
 disconnect(verticalScrollBar(), SIGNAL(valueChanged(int)), this, SLOT(on_verticalScrollBar_valueChanged(int)));
 centerOn(h);
 connect(verticalScrollBar(), SIGNAL(valueChanged(int)), this, SLOT(on_verticalScrollBar_valueChanged(int)));
+
 }
 
 void DocumentView::on_syncpage(int index, const QPointF& pagePos)
