@@ -25,8 +25,18 @@ modified by Pascal Brachet
 #include <QtCore>
 #include <QtXml>
 #include <QtGui>
+#include <QGraphicsView>
+#include <QPrinter>
+
+#if defined(POPPLER20)
+#include "texmaker_popplerqt20/poppler-qt4.h"
+#elif defined(POPPLER22)
+#include "texmaker_popplerqt22/poppler-qt4.h"
+#else
+#include <poppler-qt4.h>
+#endif
+
 
-#include "poppler-qt4.h"
 
 #include "pageitem.h"
 #include "presentationview.h"
