@@ -10,7 +10,11 @@
  ***************************************************************************/
 
 #include "findwidget.h"
+
+#include <QDebug>
+#include <QTextCursor>
 #include <QMessageBox>
+#include "geticon.h"
 
 FindWidget::FindWidget(QWidget* parent)
     : QWidget( parent)
@@ -22,10 +26,13 @@ ui.findButton->setShortcut(Qt::Key_Return);
 ui.findButton->setToolTip("Return");
 ui.closeButton->setShortcut(Qt::Key_Escape);
 ui.closeButton->setToolTip("Escape");
+//ui.closeButton->setIcon(getIcon(":/images/fileclose.png"));
 ui.moreButton->setCheckable(true);
 ui.moreButton->setAutoDefault(false);
 connect(ui.moreButton, SIGNAL(toggled(bool)), this, SLOT(expand(bool)));
-ui.checkRegExp->setChecked( FALSE );
+ui.checkRegExp->setChecked( false );
+ui.checkSelection->setChecked( false );
+connect(ui.checkSelection, SIGNAL(toggled(bool)), this, SLOT(updateSelection(bool)));
 ui.extension->hide();
 updateGeometry();
  }
@@ -37,7 +44,13 @@ FindWidget::~FindWidget()
 
 void FindWidget::doFind()
 {
-if ( !editor ) return;
+if ( !editor )
+  {
+  startpos=-1; 
+  endpos=-1;
+  return;
+  }
+
 if (ui.checkRegExp->isChecked())
   {
   QRegExp regex(ui.comboFind->currentText());
@@ -47,17 +60,35 @@ if (ui.checkRegExp->isChecked())
     return;
     }
   }
-if ( !editor->search( ui.comboFind->currentText(), ui.checkCase->isChecked(),	ui.checkWords->isChecked(), ui.radioForward->isChecked(), !ui.checkBegin->isChecked(), ui.checkRegExp->isChecked()) )
-   {
-   ui.checkBegin->setChecked( TRUE );
-   }
-else ui.checkBegin->setChecked( FALSE );
+int result=-1;  
+if (ui.checkSelection->isChecked())
+  {
+  if ((startpos>-1) && (endpos>-1)) 
+	{
+	result=editor->searchInSelection( ui.comboFind->currentText(), ui.checkCase->isChecked(),ui.checkWords->isChecked(), ui.checkRegExp->isChecked(),startpos,endpos); 
+	if (result>-1) startpos=result;
+	else ui.checkSelection->setChecked( false );  
+	}
+  }
+else
+  {
+  startpos=-1; 
+  endpos=-1;
+
+  if ( !editor->search( ui.comboFind->currentText(), ui.checkCase->isChecked(),	ui.checkWords->isChecked(), ui.radioForward->isChecked(), !ui.checkBegin->isChecked(), ui.checkRegExp->isChecked()) )
+    {
+    ui.checkBegin->setChecked( true );
+    }
+  else ui.checkBegin->setChecked( false );
+  }
 editor->viewport()->repaint();
 }
 
 void FindWidget::doHide()
 {
 emit requestHide();
+startpos=-1; 
+endpos=-1;
 if ( editor ) 
 	{
 	editor->viewport()->repaint();
@@ -73,8 +104,45 @@ editor=ed;
 void FindWidget::expand(bool e)
 {
  ui.extension->setVisible(e);
- if (!e) ui.checkRegExp->setChecked( FALSE );
+ if (!e) 
+    {
+    ui.checkRegExp->setChecked( false );
+    ui.checkSelection->setChecked( false );
+    }
  updateGeometry();
  emit requestExtension();
- editor->viewport()->repaint();
+ if ( editor ) editor->viewport()->repaint();
 }
+
+void FindWidget::updateSelection(bool e)
+{
+ui.checkBegin->setEnabled(!e);
+if (e) ui.radioForward->setChecked(true);
+if ( !editor ) 
+  {
+  startpos=-1; 
+  endpos=-1;
+  }
+else if (e)
+  {
+  QTextCursor c=editor->textCursor();
+  if (c.hasSelection()) 
+	{
+	startpos=c.selectionStart();
+	endpos=c.selectionEnd();
+	}
+  else
+	{
+	QMessageBox::warning( this,"Texmaker", tr("Text must be selected before checking this option."));
+	startpos=-1; 
+	endpos=-1;
+	ui.checkSelection->setChecked( false );
+	}
+  }
+else
+  {
+  startpos=-1; 
+  endpos=-1;
+  }
+}
+
