@@ -35,7 +35,7 @@
 #include <QTextCodec>
 #include <QFileInfo>
 #include <QMessageBox>
-#include <QInputContext>
+#include <QLineEdit>
 #include <QTextDocumentFragment>
 
 #include "blockdata.h"
@@ -138,7 +138,7 @@ setBackgroundVisible(true);
 update();
 }
 
-bool LightLatexEditor::search( const QString &expr, bool cs, bool wo, bool forward, bool startAtCursor, bool isRegExp )
+bool LightLatexEditor::search( const QString &expr, bool cs, bool wo, bool forward, bool startAtCursor, bool isRegExp)
 {
 QTextDocument::FindFlags flags = 0;
 if (cs) flags |= QTextDocument::FindCaseSensitively;
@@ -168,6 +168,26 @@ else
 	}
 }
 
+int LightLatexEditor::searchInSelection( const QString &expr, bool cs, bool wo, bool isRegExp, int start, int end)
+{
+QTextDocument::FindFlags flags = 0;
+if (cs) flags |= QTextDocument::FindCaseSensitively;
+if (wo) flags |= QTextDocument::FindWholeWords;
+
+QTextCursor found = isRegExp?document()->find(QRegExp(expr), start, flags) : document()->find(expr, start, flags);
+
+if (found.isNull()) return -1;
+else 
+	{
+	if (found.selectionEnd()>end) return -1;
+	else
+	  {
+	  setTextCursor(found);
+	  return found.selectionEnd();
+	  }
+	}
+}
+
 int LightLatexEditor::searchLine( const QString &expr)
 {
 int result=-1;
@@ -696,7 +716,7 @@ layout->draw(&painter, offset, selections, er);
                 cursor_cpos = cpos;
                 cursor_pen = painter.pen();
             }
-#ifndef Q_WS_MAC // no visible cursor on mac
+#if !defined(Q_OS_MAC)
             if (blockSelectionCursorRect.isValid())
                 painter.fillRect(blockSelectionCursorRect, palette().text());
 #endif
@@ -807,18 +827,10 @@ if (e->modifiers() & Qt::AltModifier)
 
 	QTextCursor cursor = textCursor();
 	// get visual column
-#if (QT_VERSION >= 0x040700)
 	int column = blockSelection.columnAt(cursor.block().text(), cursor.positionInBlock());
 	if (cursor.positionInBlock() == cursor.block().length()-1) {
 	    column += (e->pos().x() - cursorRect().center().x())/QFontMetricsF(font()).width(QLatin1Char(' '));
 	}
-#else
-	int column = blockSelection.columnAt(cursor.block().text(), cursor.position() - cursor.block().position());
-if (cursor.position() - cursor.block().position() == cursor.block().length()-1) {
-	    column += (e->pos().x() - cursorRect().center().x())/QFontMetricsF(font()).width(QLatin1Char(' '));
-	}
-#endif
-
 	  blockSelection.moveAnchor(cursor.blockNumber(), column);
 	setTextCursor(blockSelection.selection());
 	viewport()->update();
@@ -989,11 +1001,8 @@ void LightLatexEditor::insertFromMimeData(const QMimeData *source)
         QTextCursor cursor = textCursor();
         cursor.beginEditBlock();
         int initialCursorPosition = cursor.position();
-#if (QT_VERSION >= 0x040700)
         int column = blockSelection.columnAt(cursor.block().text(), cursor.positionInBlock());
-#else
-	int column = blockSelection.columnAt(cursor.block().text(), cursor.position() - cursor.block().position());
-#endif
+
         cursor.insertText(lines.first());
         for (int i = 1; i < lines.count(); ++i) {
             QTextBlock next = cursor.block().next();
