@@ -493,19 +493,23 @@ while (i < text.length())
 	} break;
 	case StateGraphicAsyMath: {
 		tmp=text.at( i );
-		if (tmp== '$') {
+		if (tmp== '"') {
 			setFormat( i, 1,ColorMath);
 			blockData->code[i]=1;
 			state=StateGraphicAsy;
-			if (next=='$')
-				{
-				i++;
-				if ( i < text.length())
-					{
-					setFormat( i, 1,ColorMath);
-					blockData->code[i]=1;
-					}
-				}
+// 		if (tmp== '$') {
+// 			setFormat( i, 1,ColorMath);
+// 			blockData->code[i]=1;
+// 			state=StateGraphicAsy;
+// 			if (next=='$')
+// 				{
+// 				i++;
+// 				if ( i < text.length())
+// 					{
+// 					setFormat( i, 1,ColorMath);
+// 					blockData->code[i]=1;
+// 					}
+// 				}
 		} else if (tmp== '\\') {
 			if (next==']')
 				{
@@ -938,20 +942,25 @@ while (i < text.length())
 			state=StateGraphicAsyCommand;
 			}
  		} else
-		if (tmp=='$') {
+		if (tmp=='"') {
 			setFormat( i, 1,ColorMath);
 			blockData->code[i]=1;
 			state=StateGraphicAsyMath;
-			if (next=='$')
-				{
-				i++;
-				if ( i < text.length())
-					{
-					setFormat( i, 1,ColorMath);
-					blockData->code[i]=1;
-					}
-				}
 			buffer = QString::null;
+// 		if (tmp=='$') {
+// 			setFormat( i, 1,ColorMath);
+// 			blockData->code[i]=1;
+// 			state=StateGraphicAsyMath;
+// 			if (next=='$')
+// 				{
+// 				i++;
+// 				if ( i < text.length())
+// 					{
+// 					setFormat( i, 1,ColorMath);
+// 					blockData->code[i]=1;
+// 					}
+// 				}
+// 			buffer = QString::null;
 		} else
 		if (tmp== '/' && next=='/'){
 			setFormat( i, 1,ColorComment);
@@ -1524,19 +1533,23 @@ while (i < text.length())
 
 	case StateGraphicMath: {
 		tmp=text.at( i );
-		if (tmp== '$') {
+		if (tmp== '"') {
 			setFormat( i, 1,ColorMath);
 			blockData->code[i]=1;
 			state=StateGraphic;
-			if (next=='$')
-				{
-				i++;
-				if ( i < text.length())
-					{
-					setFormat( i, 1,ColorMath);
-					blockData->code[i]=1;
-					}
-				}
+// 		if (tmp== '$') {
+// 			setFormat( i, 1,ColorMath);
+// 			blockData->code[i]=1;
+// 			state=StateGraphic;
+// 			if (next=='$')
+// 				{
+// 				i++;
+// 				if ( i < text.length())
+// 					{
+// 					setFormat( i, 1,ColorMath);
+// 					blockData->code[i]=1;
+// 					}
+// 				}
 		} else if (tmp== '\\') {
 			if (next==']')
 				{
@@ -1596,20 +1609,25 @@ while (i < text.length())
 			state=StateGraphicCommand;
 			}
 		} else
-		if (tmp=='$') {
+		if (tmp=='"') {
 			setFormat( i, 1,ColorMath);
 			blockData->code[i]=1;
 			state=StateGraphicMath;
-			if (next=='$')
-				{
-				i++;
-				if ( i < text.length())
-					{
-					setFormat( i, 1,ColorMath);
-					blockData->code[i]=1;
-					}
-				}
 			buffer = QString::null;
+// 		if (tmp=='$') {
+// 			setFormat( i, 1,ColorMath);
+// 			blockData->code[i]=1;
+// 			state=StateGraphicMath;
+// 			if (next=='$')
+// 				{
+// 				i++;
+// 				if ( i < text.length())
+// 					{
+// 					setFormat( i, 1,ColorMath);
+// 					blockData->code[i]=1;
+// 					}
+// 				}
+// 			buffer = QString::null;
 		} else
 		if (tmp== '/' && next=='/'){
 			setFormat( i, 1,ColorComment);
