@@ -21,21 +21,35 @@
 #include <QDesktopServices>
 #include <QTextCodec>
 #include <QProgressDialog>
+#include <QHeaderView>
+#include <QScrollBar>
+#include <QMessageBox>
+#include <QApplication>
+#include <QMenuBar>
+#include <QToolBar>
+#include <QDesktopWidget>
 
+#include "geticon.h"
 
-#include "poppler-qt4.h"
+#if defined(POPPLER20)
+#include "texmaker_popplerqt20/poppler-qt4.h"
+#elif defined(POPPLER22)
+#include "texmaker_popplerqt22/poppler-qt4.h"
+#else
+#include <poppler-qt4.h>
+#endif
 
 #define SYNCTEX_GZ_EXT ".synctex.gz"
 #define SYNCTEX_EXT ".synctex"
 
-PdfViewer::PdfViewer( const QString fileName, const QString externalCommand, const QString ghostscriptCommand, const QString psize,const QKeySequence edfocus,const QString SpellLang, const qreal startScale, QWidget* parent, Qt::WFlags flags)
-    : QMainWindow( parent, flags )
+PdfViewer::PdfViewer( const QString fileName, const QString externalCommand, const QString ghostscriptCommand, const QString lpopt,const QKeySequence edfocus,const QString SpellLang, const qreal startScale, QWidget* parent)
+    : QMainWindow( parent)
 {
 setWindowTitle("Texmaker : pdf preview");
-#ifdef Q_WS_MACX
+#if defined(Q_OS_MAC)
 setWindowIcon(QIcon(":/images/logo128.png"));
 #else
-setWindowIcon(QIcon(":/images/appicon.png"));
+setWindowIcon(getIcon(":/images/appicon.png"));
 #endif
 
 #ifdef USB_VERSION
@@ -61,10 +75,11 @@ setCorner(Qt::TopLeftCorner, Qt::LeftDockWidgetArea);
 pdf_file=fileName;
 viewpdf_command=externalCommand;
 gswin32c_command=ghostscriptCommand;
-paper_size=psize;
+lp_options=lpopt;
 lastFile=fileName;
 lastPage=1;
 lastHpos=0;
+islastContinuous=true;
 lastScale=startScale;
 fileLoaded=false;
 currentPage=1;
@@ -96,7 +111,7 @@ LeftPanelStackedWidget=new QStackedWidget(StructureView);
 
 listpagesWidget=new QListWidget(LeftPanelStackedWidget);
 
-connect(LeftPanelToolBar->addAction(QIcon(":/images/pages.png"),tr("Pages")), SIGNAL(triggered()), this, SLOT(ShowListPages()));
+connect(LeftPanelToolBar->addAction(getIcon(":/images/pages.png"),tr("Pages")), SIGNAL(triggered()), this, SLOT(ShowListPages()));
 LeftPanelStackedWidget->addWidget(listpagesWidget);
 
 LeftPanelToolBar->addSeparator();
@@ -105,13 +120,17 @@ StructureTreeView=new QTreeView(LeftPanelStackedWidget);
 StructureTreeView->header()->hide();
 StructureTreeView->setEditTriggers(QAbstractItemView::NoEditTriggers);
 StructureTreeView->header()->setHorizontalScrollMode(QAbstractItemView::ScrollPerPixel);
-StructureTreeView->header()->setResizeMode(QHeaderView::ResizeToContents);
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
+StructureTreeView->header()->setSectionResizeMode(QHeaderView::ResizeToContents);
+#else
+StructureTreeView->header()->setResizeMode(0, QHeaderView::ResizeToContents);
+#endif
 StructureTreeView->header()->setStretchLastSection(false);
 StructureTreeView->setIndentation(15);
 StructureTreeView->setModel(0);
 
 
-connect(LeftPanelToolBar->addAction(QIcon(":/images/structure.png"),tr("Structure")), SIGNAL(triggered()), this, SLOT(ShowStructure()));
+connect(LeftPanelToolBar->addAction(getIcon(":/images/structure.png"),tr("Structure")), SIGNAL(triggered()), this, SLOT(ShowStructure()));
 LeftPanelStackedWidget->addWidget(StructureTreeView);
 
 showingListPages=true;
@@ -143,7 +162,7 @@ setCentralWidget(centralFrame);
 
 
 QMenu *fileMenu = menuBar()->addMenu(tr("&File"));
-//printAct = new QAction(QIcon(":/images/print.png"), tr("Print"), this);
+//printAct = new QAction(getIcon(":/images/print.png"), tr("Print"), this);
 //connect(printAct, SIGNAL(triggered()), this, SLOT(printPdf()));
 //fileMenu->addAction(printAct);
 fileMenu->addAction(tr("Exit"), this, SLOT(close()),Qt::CTRL+Qt::Key_Q);
@@ -158,29 +177,29 @@ editMenu->addAction(findAct);
 QToolBar *toolBar = addToolBar("Pdf controls");
 toolBar->setObjectName("Pdf controls");
 
-upAct = new QAction(QIcon(":/images/up.png"), tr("Previous"), this);
+upAct = new QAction(getIcon(":/images/up.png"), tr("Previous"), this);
 upAct->setShortcut(QKeySequence::MoveToPreviousPage);
 toolBar->addAction(upAct);
 
-downAct = new QAction(QIcon(":/images/down.png"), tr("Next"), this);
+downAct = new QAction(getIcon(":/images/down.png"), tr("Next"), this);
 downAct->setShortcut(QKeySequence::MoveToNextPage);
 toolBar->addAction(downAct);
 
 toolBar->addSeparator();
 
 QMenu *viewMenu = menuBar()->addMenu(tr("&View"));
-fitWithAct = new QAction(QIcon(":/images/zoom-fit-width.png"), tr("Fit Width"), this);
+fitWithAct = new QAction(getIcon(":/images/zoom-fit-width.png"), tr("Fit Width"), this);
 toolBar->addAction(fitWithAct);
 
-fitPageAct = new QAction(QIcon(":/images/zoom-fit-best.png"), tr("Fit Page"), this);
+fitPageAct = new QAction(getIcon(":/images/zoom-fit-best.png"), tr("Fit Page"), this);
 toolBar->addAction(fitPageAct);
 
-zoominAct = new QAction(QIcon(":/images/zoom-in.png"), tr("Zoom In"), this);
+zoominAct = new QAction(getIcon(":/images/zoom-in.png"), tr("Zoom In"), this);
 zoominAct->setShortcut(QKeySequence::ZoomIn);
 toolBar->addAction(zoominAct);
 viewMenu->addAction(zoominAct);
 
-zoomoutAct = new QAction(QIcon(":/images/zoom-out.png"), tr("Zoom Out"), this);
+zoomoutAct = new QAction(getIcon(":/images/zoom-out.png"), tr("Zoom Out"), this);
 zoomoutAct->setShortcut(QKeySequence::ZoomOut);
 toolBar->addAction(zoomoutAct);
 viewMenu->addAction(zoomoutAct);
@@ -210,12 +229,12 @@ viewMenu->addSeparator();
 viewMenu->addAction(StructureView->toggleViewAction());
 
 
-historyBackAct = new QAction(QIcon(":/images/errorprev.png"), tr("Previous Position"), this);
+historyBackAct = new QAction(getIcon(":/images/errorprev.png"), tr("Previous Position"), this);
 historyBackAct->setShortcut(QKeySequence::Back);
 //connect(historyBackAct, SIGNAL(triggered()), this, SLOT(historyBack()));
 LeftPanelToolBar->addAction(historyBackAct);
 
-historyForwardAct = new QAction(QIcon(":/images/errornext.png"), tr("Next Position"), this);
+historyForwardAct = new QAction(getIcon(":/images/errornext.png"), tr("Next Position"), this);
 historyForwardAct->setShortcut(QKeySequence::Forward);
 //connect(historyForwardAct, SIGNAL(triggered()), this, SLOT(historyForward()));
 LeftPanelToolBar->addAction(historyForwardAct);
@@ -241,8 +260,10 @@ toolBar->addSeparator();
 searchLineEdit = new QLineEdit(toolBar);
 toolBar->addWidget(searchLineEdit);
 
-findButton=new QPushButton(tr("Find"),toolBar);
-toolBar->addWidget(findButton);
+searchAct=new QAction(getIcon(":/images/pdffind.png"), tr("Find"), this);
+toolBar->addAction(searchAct);
+//findButton=new QPushButton(tr("Find"),toolBar);
+//toolBar->addWidget(findButton);
 
 
 toolBar->addSeparator();
@@ -250,17 +271,18 @@ QWidget* spacer = new QWidget();
 spacer->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
 toolBar->addWidget(spacer);
 
-printAct = new QAction(QIcon(":/images/print.png"), tr("Print"), this);
+printAct = new QAction(getIcon(":/images/print.png"), tr("Print"), this);
 toolBar->addAction(printAct);
 
-externAct = new QAction(QIcon(":/images/viewpdf.png"), tr("External Viewer"), this);
+externAct = new QAction(getIcon(":/images/viewpdf.png"), tr("External Viewer"), this);
 toolBar->addAction(externAct);
 
-checkerAct = new QAction(QIcon(":/images/pdfchecker.png"), tr("Check Spelling and Grammar on this page"), this);
+checkerAct = new QAction(getIcon(":/images/pdfchecker.png"), tr("Check Spelling and Grammar on this page"), this);
 toolBar->addAction(checkerAct);
 
 searchLineEdit->setEnabled(false);
-findButton->setEnabled(false);
+searchAct->setEnabled(false);
+//findButton->setEnabled(false);
 scaleComboBox->setEnabled(false);
 upAct->setEnabled(false);
 downAct->setEnabled(false);
@@ -332,7 +354,8 @@ if (pdfview->open(fn))
   doc->setRenderHint(Poppler::Document::TextAntialiasing);
   searchLocation = QRectF();
   searchLineEdit->setEnabled(true);
-  findButton->setEnabled(true);
+  searchAct->setEnabled(true);
+  //findButton->setEnabled(true);
   scaleComboBox->setEnabled(true);
   upAct->setEnabled(false);
   downAct->setEnabled(true);
@@ -340,13 +363,13 @@ if (pdfview->open(fn))
   fitPageAct->setEnabled(true);
   zoominAct->setEnabled(true);
   zoomoutAct->setEnabled(true);
-  continuousModeAction->setEnabled(true);
+  continuousModeAction->setEnabled(true);//
   twoPagesModeAction->setEnabled(true);
   rotateLeftAction->setEnabled(true);
   rotateRightAction->setEnabled(true);
   presentationAction->setEnabled(true);
-  
-  pdfview->setContinousMode(true);
+  continuousModeAction->setChecked(islastContinuous);//
+  pdfview->setContinousMode(islastContinuous);
   pdfview->setTwoPagesMode(false);
   pdfview->show();
   
@@ -402,7 +425,8 @@ else
   QMessageBox::warning( this,tr("Error"),tr("File not found"));
   fileLoaded=false;
   searchLineEdit->setEnabled(false);
-  findButton->setEnabled(false);
+  searchAct->setEnabled(false);
+  //findButton->setEnabled(false);
   scaleComboBox->setEnabled(false);
   upAct->setEnabled(false);
   downAct->setEnabled(false);
@@ -438,7 +462,8 @@ connect(zoomoutAct, SIGNAL(triggered()), this, SLOT(zoomOut()));
 connect(zoomCustom, SIGNAL(returnPressed()),this, SLOT(userZoom()));
 connect(scaleComboBox, SIGNAL(currentIndexChanged(QString)),this, SLOT(scaleDocumentZoom(QString)));
 connect(searchLineEdit, SIGNAL(returnPressed()), this, SLOT(searchDocument()));
-connect(findButton, SIGNAL(clicked()), this, SLOT(searchDocument()));
+connect(searchAct, SIGNAL(triggered()), this, SLOT(searchDocument()));
+//connect(findButton, SIGNAL(clicked()), this, SLOT(searchDocument()));
 connect(historyBackAct, SIGNAL(triggered()), this, SLOT(historyBack()));
 connect(historyForwardAct, SIGNAL(triggered()), this, SLOT(historyForward()));
 connect(printAct, SIGNAL(triggered()), this, SLOT(printPdf()));
@@ -477,7 +502,8 @@ disconnect(zoomoutAct, SIGNAL(triggered()), this, SLOT(zoomOut()));
 disconnect(zoomCustom, SIGNAL(returnPressed()),this, SLOT(userZoom()));
 disconnect(scaleComboBox, SIGNAL(currentIndexChanged(QString)),this, SLOT(scaleDocumentZoom(QString)));
 disconnect(searchLineEdit, SIGNAL(returnPressed()), this, SLOT(searchDocument()));
-disconnect(findButton, SIGNAL(clicked()), this, SLOT(searchDocument()));
+disconnect(searchAct, SIGNAL(triggered()), this, SLOT(searchDocument()));
+//disconnect(findButton, SIGNAL(clicked()), this, SLOT(searchDocument()));
 disconnect(historyBackAct, SIGNAL(triggered()), this, SLOT(historyBack()));
 disconnect(historyForwardAct, SIGNAL(triggered()), this, SLOT(historyForward()));
 disconnect(printAct, SIGNAL(triggered()), this, SLOT(printPdf()));
@@ -911,17 +937,17 @@ prefixFile=QString(QUrl::toPercentEncoding(prefixFile));
 prefixFile.remove("%");
 QString tempFile=tempDir+"/"+prefixFile+".html";
 QTextCodec *codec = QTextCodec::codecForName("UTF-8");
-#if defined( Q_WS_X11 )
+#if defined(Q_OS_UNIX) && !defined(Q_OS_MAC)
 #ifdef USB_VERSION
 QString atdloc=QCoreApplication::applicationDirPath()+"/";
 #else
 QString atdloc=PREFIX"/share/texmaker/";
 #endif
 #endif
-#if defined( Q_WS_MACX )
+#if defined(Q_OS_MAC)
 QString atdloc=QCoreApplication::applicationDirPath() + "/../Resources/";
 #endif
-#if defined(Q_WS_WIN)
+#if defined(Q_OS_WIN32)
 QString atdloc=QCoreApplication::applicationDirPath() + "/";
 #endif
 QString pdf_text=doc->page(currentPage-1)->text(QRectF(),Poppler::Page::PhysicalLayout);
@@ -1034,18 +1060,22 @@ switch(printDlg.printRange())
 	  lastPage = doc->numPages();
   }
 
-if(!printer.printerName().isEmpty()) 
-  {
-#ifdef Q_WS_WIN
+//if(!printer.printerName().isEmpty()) 
+//  {
+#if defined(Q_OS_WIN32)
 pdfview->print(&printer);
 #else
   QStringList args;
   args << "lp";
+  if(!printer.printerName().isEmpty()) 
+  {
   if (!printer.printerName().contains(" ")) args << QString("-d %1").arg(printer.printerName());//.replace(" ","_"));
+  }
   args << QString("-n %1").arg(printer.copyCount());
 //  args << QString("-t \"%1\"").arg(printer.docName());
   args << QString("-P %1-%2").arg(firstPage).arg(lastPage);
-  args << "-o fitplot";
+  args << lp_options;
+//  args << "-o fitplot";
   switch(printer.duplex()) 
       {
       case QPrinter::DuplexNone:
@@ -1074,10 +1104,8 @@ pdfview->print(&printer);
   if(QProcess::execute(command) == 0) return;
   else pdfview->print(&printer);
 #endif
-  }
-else return;
-
-
+//  }
+//else return;
 }
 
 void PdfViewer::slotItemClicked(QListWidgetItem* item)
@@ -1254,6 +1282,7 @@ pdfview->presentation();
 void PdfViewer::on_currentTab_continuousModeChanged(bool continuousMode)
 {
 continuousModeAction->setChecked(continuousMode);
+islastContinuous=continuousMode;
 }
 
 void PdfViewer::on_currentTab_twoPagesModeChanged(bool twoPagesMode)
