@@ -23,14 +23,25 @@
 #include <QDesktopServices>
 #include <QTextCodec>
 #include <QProgressDialog>
+#include <QHeaderView>
+#include <QScrollBar>
+#include <QMessageBox>
+#include <QApplication>
 
+#include "geticon.h"
 
-#include "poppler-qt4.h"
+#if defined(POPPLER20)
+#include "texmaker_popplerqt20/poppler-qt4.h"
+#elif defined(POPPLER22)
+#include "texmaker_popplerqt22/poppler-qt4.h"
+#else
+#include <poppler-qt4.h>
+#endif
 
 #define SYNCTEX_GZ_EXT ".synctex.gz"
 #define SYNCTEX_EXT ".synctex"
 
-PdfViewerWidget::PdfViewerWidget( const QString fileName, const QString externalCommand, const QString ghostscriptCommand, const QString psize,const QKeySequence edfocus,const QString SpellLang, const qreal startScale ,QWidget* parent)
+PdfViewerWidget::PdfViewerWidget( const QString fileName, const QString externalCommand, const QString ghostscriptCommand, const QString lpopt,const QKeySequence edfocus,const QString SpellLang, const qreal startScale ,QWidget* parent)
     : QWidget( parent)
 {
 spell_lang=SpellLang;
@@ -38,16 +49,16 @@ KeySequenceEditorFocus=edfocus;
 pdf_file=fileName;
 viewpdf_command=externalCommand;
 gswin32c_command=ghostscriptCommand;
-paper_size=psize;
+lp_options=lpopt;
 lastFile=fileName;
 lastPage=1;
 lastHpos=0;
+islastContinuous=true;
 lastScale=startScale;
 fileLoaded=false;
 currentPage=1;
 
 
-
 doc = 0;
 scanner=NULL;
 path= QPainterPath();
@@ -113,40 +124,40 @@ centralToolBarBis->setMovable(false);
 centralToolBarBis->setIconSize(QSize(16,16 ));
 centralToolBarBis->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum);
 
-toggleStructAct=new QAction(QIcon(":/images/structure.png"),tr("Show/Hide Table of contents"),this);
+toggleStructAct=new QAction(getIcon(":/images/structure.png"),tr("Show/Hide Table of contents"),this);
 connect(toggleStructAct, SIGNAL(triggered()), this, SLOT(ToggleStructure()));
 centralToolBarBis->addAction(toggleStructAct);
 
 centralToolBarBis->addSeparator();
 
-upAct = new QAction(QIcon(":/images/up.png"), tr("Previous"), this);
+upAct = new QAction(getIcon(":/images/up.png"), tr("Previous"), this);
 //upAct->setShortcut(QKeySequence::MoveToPreviousPage);
 centralToolBarBis->addAction(upAct);
 
-downAct = new QAction(QIcon(":/images/down.png"), tr("Next"), this);
+downAct = new QAction(getIcon(":/images/down.png"), tr("Next"), this);
 //downAct->setShortcut(QKeySequence::MoveToNextPage);
 centralToolBarBis->addAction(downAct);
 
 centralToolBarBis->addSeparator();
 
-fitWithAct = new QAction(QIcon(":/images/zoom-fit-width.png"), tr("Fit Width"), this);
+fitWithAct = new QAction(getIcon(":/images/zoom-fit-width.png"), tr("Fit Width"), this);
 centralToolBarBis->addAction(fitWithAct);
 
-fitPageAct = new QAction(QIcon(":/images/zoom-fit-best.png"), tr("Fit Page"), this);
+fitPageAct = new QAction(getIcon(":/images/zoom-fit-best.png"), tr("Fit Page"), this);
 centralToolBarBis->addAction(fitPageAct);
 
-zoominAct = new QAction(QIcon(":/images/zoom-in.png"), tr("Zoom In"), this);
+zoominAct = new QAction(getIcon(":/images/zoom-in.png"), tr("Zoom In"), this);
 zoominAct->setShortcut(QKeySequence::ZoomIn);
 centralToolBarBis->addAction(zoominAct);
 
 
-zoomoutAct = new QAction(QIcon(":/images/zoom-out.png"), tr("Zoom Out"), this);
+zoomoutAct = new QAction(getIcon(":/images/zoom-out.png"), tr("Zoom Out"), this);
 zoomoutAct->setShortcut(QKeySequence::ZoomOut);
 centralToolBarBis->addAction(zoomoutAct);
 
 
 optionsButton = new QToolButton(centralToolBarBis);
-optionsButton->setIcon(QIcon(":/images/viewoptions.png"));
+optionsButton->setIcon(getIcon(":/images/viewoptions.png"));
 optionsButton->setText("");
 optionsButton->setPopupMode(QToolButton::InstantPopup);
 QMenu *viewMenu = new QMenu(optionsButton);
@@ -198,8 +209,10 @@ searchLineEdit = new QLineEdit(centralToolBarBis);
 
 centralToolBarBis->addWidget(searchLineEdit);
 
-findButton=new QPushButton(tr("Find"),centralToolBarBis);
-centralToolBarBis->addWidget(findButton);
+searchAct=new QAction(getIcon(":/images/pdffind.png"), tr("Find"), this);
+centralToolBarBis->addAction(searchAct);
+// findButton=new QPushButton(tr("Find"),centralToolBarBis);
+// centralToolBarBis->addWidget(findButton);
 
 
 centralToolBarBis->addSeparator();
@@ -207,12 +220,12 @@ QWidget* spacer = new QWidget();
 spacer->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
 centralToolBarBis->addWidget(spacer);
 
-historyBackAct = new QAction(QIcon(":/images/errorprev.png"), tr("Previous Position"), this);
+historyBackAct = new QAction(getIcon(":/images/errorprev.png"), tr("Previous Position"), this);
 //historyBackAct->setShortcut(QKeySequence::Back);
 //connect(historyBackAct, SIGNAL(triggered()), this, SLOT(historyBack()));
 //centralToolBarBis->addAction(historyBackAct);
 
-historyForwardAct = new QAction(QIcon(":/images/errornext.png"), tr("Next Position"), this);
+historyForwardAct = new QAction(getIcon(":/images/errornext.png"), tr("Next Position"), this);
 //historyForwardAct->setShortcut(QKeySequence::Forward);
 //connect(historyForwardAct, SIGNAL(triggered()), this, SLOT(historyForward()));
 //centralToolBarBis->addAction(historyForwardAct);
@@ -221,13 +234,13 @@ connect( this, SIGNAL( backwardAvailable( bool ) ), historyBackAct, SLOT( setEna
 connect( this, SIGNAL( forwardAvailable( bool ) ), historyForwardAct, SLOT( setEnabled( bool ) ) );
 //centralToolBarBis->addSeparator();
 
-printAct = new QAction(QIcon(":/images/print.png"), tr("Print"), this);
+printAct = new QAction(getIcon(":/images/print.png"), tr("Print"), this);
 centralToolBarBis->addAction(printAct);
 
-externAct = new QAction(QIcon(":/images/viewpdf.png"), tr("External Viewer"), this);
+externAct = new QAction(getIcon(":/images/viewpdf.png"), tr("External Viewer"), this);
 centralToolBarBis->addAction(externAct);
 
-checkerAct = new QAction(QIcon(":/images/pdfchecker.png"), tr("Check Spelling and Grammar on this page"), this);
+checkerAct = new QAction(getIcon(":/images/pdfchecker.png"), tr("Check Spelling and Grammar on this page"), this);
 centralToolBarBis->addAction(checkerAct);
 
 
@@ -251,7 +264,11 @@ StructureTreeView=new QTreeView(splitter);
 StructureTreeView->header()->hide();
 StructureTreeView->setEditTriggers(QAbstractItemView::NoEditTriggers);
 StructureTreeView->header()->setHorizontalScrollMode(QAbstractItemView::ScrollPerPixel);
-StructureTreeView->header()->setResizeMode(QHeaderView::ResizeToContents);
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
+StructureTreeView->header()->setSectionResizeMode(QHeaderView::ResizeToContents);
+#else
+StructureTreeView->header()->setResizeMode(0, QHeaderView::ResizeToContents);
+#endif
 StructureTreeView->header()->setStretchLastSection(false);
 StructureTreeView->setIndentation(15);
 StructureTreeView->setFrameStyle(QFrame::NoFrame);
@@ -271,7 +288,8 @@ showingStructure=false;
 StructureTreeView->hide();
 
 searchLineEdit->setEnabled(false);
-findButton->setEnabled(false);
+searchAct->setEnabled(false);
+//findButton->setEnabled(false);
 scaleComboBox->setEnabled(false);
 upAct->setEnabled(false);
 downAct->setEnabled(false);
@@ -325,18 +343,20 @@ if (scanner != NULL)
 doc = Poppler::Document::load(fn);
 if (pdfview->open(fn)) 
   {
+
   listpagesWidget->clear();
   doc=pdfview->doc();
   doc->setRenderHint(Poppler::Document::Antialiasing);
   doc->setRenderHint(Poppler::Document::TextAntialiasing);
   searchLocation = QRectF();
-  pdfview->setContinousMode(true);
-  continuousModeAction->setChecked(true);
+  pdfview->setContinousMode(islastContinuous);//
+  continuousModeAction->setChecked(islastContinuous);//
   pdfview->setTwoPagesMode(false);
   twoPagesModeAction->setChecked(false);
   pdfview->show();
   searchLineEdit->setEnabled(true);
-  findButton->setEnabled(true);
+  searchAct->setEnabled(true);
+  //findButton->setEnabled(true);
   scaleComboBox->setEnabled(true);
   upAct->setEnabled(false);
   downAct->setEnabled(true);
@@ -348,6 +368,7 @@ if (pdfview->open(fn))
   StructureTreeView->setModel(pdfview->outlineModel());
   QString syncFile = QFileInfo(fn).canonicalFilePath();
   scanner = synctex_scanner_new_with_output_file(syncFile.toUtf8().data(), NULL, 1);
+
   if ((fn==lastFile) && (lpage <= doc->numPages()) && (lpage>0))
     {
     currentPage=lpage;
@@ -400,7 +421,8 @@ if (pdfview->open(fn))
       QMessageBox::warning( this,tr("Error"),tr("File not found"));
       fileLoaded=false;
       searchLineEdit->setEnabled(false);
-      findButton->setEnabled(false);
+      searchAct->setEnabled(false);
+      //findButton->setEnabled(false);
       scaleComboBox->setEnabled(false);
       upAct->setEnabled(false);
       downAct->setEnabled(false);
@@ -418,7 +440,6 @@ if (pdfview->open(fn))
 
 void PdfViewerWidget::connectActions()
 {
-connect(findButton, SIGNAL(clicked()), this, SLOT(searchDocument()));
 connect(upAct, SIGNAL(triggered()), this, SLOT(pageUp()));
 connect(downAct, SIGNAL(triggered()), this, SLOT(pageDown()));
 connect(listpagesWidget, SIGNAL(itemActivated ( QListWidgetItem*)), this, SLOT(slotItemClicked(QListWidgetItem*)));
@@ -431,7 +452,8 @@ connect(zoomoutAct, SIGNAL(triggered()), this, SLOT(zoomOut()));
 connect(zoomCustom, SIGNAL(returnPressed()),this, SLOT(userZoom()));
 connect(scaleComboBox, SIGNAL(currentIndexChanged(QString)),this, SLOT(scaleDocumentZoom(QString)));
 connect(searchLineEdit, SIGNAL(returnPressed()), this, SLOT(searchDocument()));
-connect(findButton, SIGNAL(clicked()), this, SLOT(searchDocument()));
+connect(searchAct, SIGNAL(triggered()), this, SLOT(searchDocument()));
+//connect(findButton, SIGNAL(clicked()), this, SLOT(searchDocument()));
 connect(historyBackAct, SIGNAL(triggered()), this, SLOT(historyBack()));
 connect(historyForwardAct, SIGNAL(triggered()), this, SLOT(historyForward()));
 connect(printAct, SIGNAL(triggered()), this, SLOT(printPdf()));
@@ -457,7 +479,6 @@ connect(presentationAction, SIGNAL(triggered()),this, SLOT(on_presentation_trigg
 
 void PdfViewerWidget::disconnectActions()
 {
-disconnect(findButton, SIGNAL(clicked()), this, SLOT(searchDocument()));
 disconnect(upAct, SIGNAL(triggered()), this, SLOT(pageUp()));
 disconnect(downAct, SIGNAL(triggered()), this, SLOT(pageDown()));
 disconnect(listpagesWidget, SIGNAL(itemActivated ( QListWidgetItem*)), this, SLOT(slotItemClicked(QListWidgetItem*)));
@@ -470,7 +491,8 @@ disconnect(zoomoutAct, SIGNAL(triggered()), this, SLOT(zoomOut()));
 disconnect(zoomCustom, SIGNAL(returnPressed()),this, SLOT(userZoom()));
 disconnect(scaleComboBox, SIGNAL(currentIndexChanged(QString)),this, SLOT(scaleDocumentZoom(QString)));
 disconnect(searchLineEdit, SIGNAL(returnPressed()), this, SLOT(searchDocument()));
-disconnect(findButton, SIGNAL(clicked()), this, SLOT(searchDocument()));
+disconnect(searchAct, SIGNAL(triggered()), this, SLOT(searchDocument()));
+//disconnect(findButton, SIGNAL(clicked()), this, SLOT(searchDocument()));
 disconnect(historyBackAct, SIGNAL(triggered()), this, SLOT(historyBack()));
 disconnect(historyForwardAct, SIGNAL(triggered()), this, SLOT(historyForward()));
 disconnect(printAct, SIGNAL(triggered()), this, SLOT(printPdf()));
@@ -495,6 +517,7 @@ disconnect(presentationAction, SIGNAL(triggered()),this, SLOT(on_presentation_tr
 
 void PdfViewerWidget::jumpToPdfFromSource(QString sourceFile, int source_line)
 {
+
 show();
 if (windowState()==Qt::WindowMinimized) setWindowState(windowState() & ~Qt::WindowMinimized | Qt::WindowActive);
 qApp->setActiveWindow(this);
@@ -526,6 +549,7 @@ if (!found)
   gotoPage(currentPage);
   return;
   }
+
 if (synctex_display_query(scanner, name.toUtf8().data(), source_line, 0) > 0) 
   {
   int page = -1;
@@ -543,9 +567,9 @@ if (synctex_display_query(scanner, name.toUtf8().data(), source_line, 0) > 0)
   if (page > 0) 
     {
      disconnect(pdfview, SIGNAL(currentPageChanged(int)), this, SLOT(checkPage(int)));
-    QRectF r = path.boundingRect();
-    currentPage=page;
-    lastPage=currentPage;
+     QRectF r = path.boundingRect();
+     currentPage=page;
+     lastPage=currentPage;
     pdfview->showRect(currentPage-1,r);
     path.setFillRule(Qt::WindingFill);
     QTimer::singleShot(500,this, SLOT(slotHighlight()) );
@@ -904,17 +928,17 @@ prefixFile=QString(QUrl::toPercentEncoding(prefixFile));
 prefixFile.remove("%");
 QString tempFile=tempDir+"/"+prefixFile+".html";
 QTextCodec *codec = QTextCodec::codecForName("UTF-8");
-#if defined( Q_WS_X11 )
+#if defined(Q_OS_UNIX) && !defined(Q_OS_MAC)
 #ifdef USB_VERSION
 QString atdloc=QCoreApplication::applicationDirPath()+"/";
 #else
 QString atdloc=PREFIX"/share/texmaker/";
 #endif
 #endif
-#if defined( Q_WS_MACX )
+#if defined(Q_OS_MAC)
 QString atdloc=QCoreApplication::applicationDirPath() + "/../Resources/";
 #endif
-#if defined(Q_WS_WIN)
+#if defined(Q_OS_WIN32)
 QString atdloc=QCoreApplication::applicationDirPath() + "/";
 #endif
 QString pdf_text=doc->page(currentPage-1)->text(QRectF(),Poppler::Page::PhysicalLayout);
@@ -1027,18 +1051,22 @@ switch(printDlg.printRange())
 	  lastPage = doc->numPages();
   }
 
-if(!printer.printerName().isEmpty()) 
-  {
-#ifdef Q_WS_WIN
+//if(!printer.printerName().isEmpty()) 
+//  {
+#if defined(Q_OS_WIN32)
 pdfview->print(&printer);
 #else
   QStringList args;
   args << "lp";
+  if(!printer.printerName().isEmpty()) 
+  {
   if (!printer.printerName().contains(" ")) args << QString("-d %1").arg(printer.printerName());//.replace(" ","_"));
+  }
   args << QString("-n %1").arg(printer.copyCount());
 //  args << QString("-t \"%1\"").arg(printer.docName());
   args << QString("-P %1-%2").arg(firstPage).arg(lastPage);
-  args << "-o fitplot";
+  args << lp_options;
+  //args << "-o fitplot";
   switch(printer.duplex()) 
       {
       case QPrinter::DuplexNone:
@@ -1064,12 +1092,11 @@ pdfview->print(&printer);
   args << "--";
   args << QString("\"%1\"").arg(pdf_file);
   command=args.join(" ");
-  qDebug() << command;
   if(QProcess::execute(command) == 0) return;
   else pdfview->print(&printer);
 #endif
-  }
-else return;
+//  } 
+//else return; 
 
 
 }
@@ -1214,6 +1241,7 @@ pdfview->presentation();
 void PdfViewerWidget::on_currentTab_continuousModeChanged(bool continuousMode)
 {
 continuousModeAction->setChecked(continuousMode);
+islastContinuous=continuousMode;
 }
 
 void PdfViewerWidget::on_currentTab_twoPagesModeChanged(bool twoPagesMode)
